@@ -1,4 +1,7 @@
-from typing import NoReturn, Optional, Tuple, Type
+from typing import NoReturn, Optional, Tuple, Type, TypeVar
+
+from .exceptions import InvalidUnionType
+from .scalars import SCALAR_TYPES
 
 
 class StrawberryUnion:
@@ -37,8 +40,6 @@ def union(
 
     Example usages:
 
-    >>> strawberry.union("Some Thing", (int, str))
-
     >>> @strawberry.type
     ... class A: ...
     >>> @strawberry.type
@@ -46,6 +47,21 @@ def union(
     >>> strawberry.union("Name", (A, Optional[B]))
     """
 
+    # Validate types
+    if len(types) == 0:
+        raise TypeError("No types passed to `union`")
+
+    for _type in types:
+        if _type in SCALAR_TYPES:
+            raise InvalidUnionType(
+                f"Scalar type `{_type.__name__}` cannot be used in a GraphQL Union"
+            )
+
+        if not isinstance(_type, TypeVar) and not hasattr(_type, "_type_definition"):
+            raise InvalidUnionType(
+                f"Union type `{_type.__name__}` is not a Strawberry type"
+            )
+
     union_definition = StrawberryUnion(name=name, types=types, description=description)
 
     return union_definition
